@@ -26,10 +26,12 @@ namespace
             return pos + 1;                     // next to handle
         }
 
-        A2x a2x(src.substr(pos, nOct));
+//        A2x a2x(src.substr(pos, nOct));
+//        size_t ch;
+//        a2x >> oct >> ch;                       // convert substr. to octal
+
+        size_t ch = stoul(src.substr(pos, nOct), 0, 8);
 
-        size_t ch;
-        a2x >> oct >> ch;                       // convert substr. to octal
         *dest += static_cast<char>(ch);         // append the octal value
         return pos2;                            // pos. of next to handle
     }
@@ -49,9 +51,12 @@ namespace
             return pos;                         // next char to handle
         }
 
-        A2x a2x(src.substr(pos, nHex));
-        size_t ch;
-        a2x >> hex >> ch;                       // convert substr. to hex
+//        A2x a2x(src.substr(pos, nHex));
+//        size_t ch;
+//        a2x >> hex >> ch;                       // convert substr. to hex
+
+        size_t ch = stoul(src.substr(pos, nHex), 0, 16);
+
         *dest += static_cast<char>(ch);         // append the hex value
 
         return pos2;                            // pos. of next to handle
@@ -97,32 +102,3 @@ string String::unescape(string const &str)
         prefix = pos; 
     }
 }
-
-//#include <string>
-//#include <iostream>
-//using namespace std;
-//using namespace FBB;
-//
-//void out(char ch)
-//{
-//    cout << static_cast<size_t>(static_cast<unsigned char>(ch)) << ", ";
-//}
-//
-//int main()
-//{
-//    while (true)
-//    {
-//        cout << "? ";
-//        string str;
-//
-//        if (!getline(cin, str))
-//            return(0);
-//
-//        cout << str << " -> ";
-//        str = String::unescape(str);
-//        cout << str << '\n';
-//
-//        for_each(str.begin(), str.end(), out);
-//        cout << '\n';
-//    }
-//}
